Wok
Wok lib is the library behind the wok tool.
The wok binary allows to control several git repositories as a single
project.
See Wok’s README and wok --help for details on how to use the tool.
Wok lib is the library behind the wok tool.
The wok binary allows to control several git repositories as a single
project.
See Wok’s README and wok --help for details on how to use the tool.